/*
    parse_aux.c - Part of psiconv, a PSION 5 file formats converter
    Copyright (c) 1999-2004  Frodo Looijaard <frodol@dds.nl>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "config.h"
#include "compat.h"
#include <stdarg.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "common.h"

#ifdef DMALLOC
#include <dmalloc.h>
#endif


char *psiconv_make_printable(const psiconv_config config,
                             const psiconv_string_t input)
{
  int i,len;
  psiconv_u8 *intermed;
  char *output;
  int res;

  if ((res = psiconv_unicode_to_chars(config,input,&intermed)))
    return NULL;

  len = 0;
  while (intermed[len])
    len++;

  if (!(output = malloc(sizeof(*output) * (len + 1)))) {
    free(intermed);
    return NULL;
  }

  for (i = 0; i < len; i ++)
    if (intermed[i] < 0x20 || intermed[i] >= 0x7f)
      output[i] = '.';
    else
      output[i] = intermed[i];
  output[i] = 0;
  free(intermed);
  return output;
}
